==> mshow-model-1.0.0.0-20190704.145349-122-sources.jar: com/mini/mshow/model/dto/UserVisitedOverviewDto.java <==
package com.mini.mshow.model.dto;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * 用户被访问相关信息的总览
 * @author jayheo
 *
 */
public class UserVisitedOverviewDto {

	/**
	 * 名片首页被访问的人数
	 */
	private Integer pcardVisitorNum;
	/**
	 * 名片首页被访问的人次
	 */
	private Integer pcardVisitedTime;
	
	/**
	 * 专题被访问的人数
	 */
	private Integer specialVisitorNum;
	/**
	 * 专题首页被访问的人次
	 */
	private Integer specialVisitedTime;
	
	/**
	 * 活动首页被访问的人数
	 */
	private Integer activityVisitorNum;
	/**
	 * 活动首页被访问的人次
	 */
	private Integer activityVisitedTime;

	/**
	 * 相册首页被访问的人数
	 */
	private Integer albumVisitorNum;
	/**
	 * 相册首页被访问的人次
	 */
	private Integer albumVisitedTime;
	public Integer getPcardVisitorNum() {
		return pcardVisitorNum;
	}
	public void setPcardVisitorNum(Integer pcardVisitorNum) {
		this.pcardVisitorNum = pcardVisitorNum;
	}
	public Integer getPcardVisitedTime() {
		return pcardVisitedTime;
	}
	public void setPcardVisitedTime(Integer pcardVisitedTime) {
		this.pcardVisitedTime = pcardVisitedTime;
	}
	public Integer getSpecialVisitorNum() {
		return specialVisitorNum;
	}
	public void setSpecialVisitorNum(Integer specialVisitorNum) {
		this.specialVisitorNum = specialVisitorNum;
	}
	public Integer getSpecialVisitedTime() {
		return specialVisitedTime;
	}
	public void setSpecialVisitedTime(Integer specialVisitedTime) {
		this.specialVisitedTime = specialVisitedTime;
	}
	public Integer getActivityVisitorNum() {
		return activityVisitorNum;
	}
	public void setActivityVisitorNum(Integer activityVisitorNum) {
		this.activityVisitorNum = activityVisitorNum;
	}
	public Integer getActivityVisitedTime() {
		return activityVisitedTime;
	}
	public void setActivityVisitedTime(Integer activityVisitedTime) {
		this.activityVisitedTime = activityVisitedTime;
	}
	public Integer getAlbumVisitorNum() {
		return albumVisitorNum;
	}
	public void setAlbumVisitorNum(Integer albumVisitorNum) {
		this.albumVisitorNum = albumVisitorNum;
	}
	public Integer getAlbumVisitedTime() {
		return albumVisitedTime;
	}
	public void setAlbumVisitedTime(Integer albumVisitedTime) {
		this.albumVisitedTime = albumVisitedTime;
	}

	@Override
	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}
}

==> mshow-model-1.0.0.0-20190805.112258-159-sources.jar: com/mini/mshow/model/dto/UserVisitedOverviewDto.java <==
package com.mini.mshow.model.dto;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * 用户被访问相关信息的总览
 * @author jayheo
 *
 */
public class UserVisitedOverviewDto {

	/**
	 * 名片首页被访问的人数
	 */
	private Integer pcardVisitorNum;
	/**
	 * 名片首页被访问的人次
	 */
	private Integer pcardVisitedTime;
	
	/**
	 * 专题被访问的人数
	 */
	private Integer specialVisitorNum;
	/**
	 * 专题首页被访问的人次
	 */
	private Integer specialVisitedTime;
	
	/**
	 * 活动首页被访问的人数
	 */
	private Integer activityVisitorNum;
	/**
	 * 活动首页被访问的人次
	 */
	private Integer activityVisitedTime;

	/**
	 * 相册首页被访问的人数
	 */
	private Integer albumVisitorNum;
	/**
	 * 相册首页被访问的人次
	 */
	private Integer albumVisitedTime;
	

	/**
	 * 相册首页被访问的人数
	 */
	private Integer goodsVisitorNum;
	/**
	 * 相册首页被访问的人次
	 */
	private Integer goodsVisitedTime;
	public Integer getPcardVisitorNum() {
		return pcardVisitorNum;
	}
	public void setPcardVisitorNum(Integer pcardVisitorNum) {
		this.pcardVisitorNum = pcardVisitorNum;
	}
	public Integer getPcardVisitedTime() {
		return pcardVisitedTime;
	}
	public void setPcardVisitedTime(Integer pcardVisitedTime) {
		this.pcardVisitedTime = pcardVisitedTime;
	}
	public Integer getSpecialVisitorNum() {
		return specialVisitorNum;
	}
	public void setSpecialVisitorNum(Integer specialVisitorNum) {
		this.specialVisitorNum = specialVisitorNum;
	}
	public Integer getSpecialVisitedTime() {
		return specialVisitedTime;
	}
	public void setSpecialVisitedTime(Integer specialVisitedTime) {
		this.specialVisitedTime = specialVisitedTime;
	}
	public Integer getActivityVisitorNum() {
		return activityVisitorNum;
	}
	public void setActivityVisitorNum(Integer activityVisitorNum) {
		this.activityVisitorNum = activityVisitorNum;
	}
	public Integer getActivityVisitedTime() {
		return activityVisitedTime;
	}
	public void setActivityVisitedTime(Integer activityVisitedTime) {
		this.activityVisitedTime = activityVisitedTime;
	}
	public Integer getAlbumVisitorNum() {
		return albumVisitorNum;
	}
	public void setAlbumVisitorNum(Integer albumVisitorNum) {
		this.albumVisitorNum = albumVisitorNum;
	}
	public Integer getAlbumVisitedTime() {
		return albumVisitedTime;
	}
	public void setAlbumVisitedTime(Integer albumVisitedTime) {
		this.albumVisitedTime = albumVisitedTime;
	}
	public Integer getGoodsVisitorNum() {
		return goodsVisitorNum;
	}
	public void setGoodsVisitorNum(Integer goodsVisitorNum) {
		this.goodsVisitorNum = goodsVisitorNum;
	}
	public Integer getGoodsVisitedTime() {
		return goodsVisitedTime;
	}
	public void setGoodsVisitedTime(Integer goodsVisitedTime) {
		this.goodsVisitedTime = goodsVisitedTime;
	}
	@Override
	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}
}
